@@ -270,6 +270,8 @@ function task_postinst_permissions {
     chmod 700 /var/log/puppetlabs/puppetdb
     chown puppetdb:puppetdb $app_data
     chmod 770 $app_data
+    chown puppetdb:puppetdb $projconfdir
+    chmod 750 $projconfdir
 }
 
 # Install logrotate (usually el7, fedora 16 and above)
