@@ -1,4 +1,4 @@
-(def pdb-version "3.2.3")
+(def pdb-version "3.2.4")
 
 (defn deploy-info
   "Generate deployment information from the URL supplied and the username and
@@ -37,6 +37,7 @@
                  [org.clojure/math.combinatorics "0.0.4"]
                  [org.clojure/math.numeric-tower "0.0.4"]
                  [org.clojure/tools.logging "0.3.1"]
+                 [org.clojure/core.memoize "0.5.8"]
                  [puppetlabs/tools.namespace "0.2.4.1"]
                  [clj-stacktrace "0.2.8"]
                  [metrics-clojure "0.7.0" :exclusions [org.clojure/clojure org.slf4j/slf4j-api]]
@@ -44,6 +45,7 @@
                  [org.clojure/java.jmx "0.3.1"]
                  ;; Filesystem utilities
                  [me.raynes/fs "1.4.5"]
+                 [org.apache.commons/commons-lang3 "3.3.1"]
                  ;; Version information
                  [puppetlabs/dujour-version-check "0.1.3"]
                  ;; Job scheduling
@@ -133,7 +135,7 @@
              :ezbake {:dependencies ^:replace [[puppetlabs/puppetdb ~pdb-version]
                                                [org.clojure/tools.nrepl "0.2.3"]]
                       :name "puppetdb"
-                      :plugins [[puppetlabs/lein-ezbake "0.3.21"
+                      :plugins [[puppetlabs/lein-ezbake "0.3.23"
                                  :exclusions [org.clojure/clojure]]]}
              :testutils {:source-paths ^:replace ["test"]}
              :ci {:plugins [[lein-pprint "1.1.1"]]}}
