@@ -1,6 +1,5 @@
 (ns puppetlabs.puppetdb.utils
   (:require [puppetlabs.kitchensink.core :as kitchensink]
-            [puppetlabs.puppetdb.scf.storage-utils]
             [clojure.tools.logging :as log]
             [clojure.string :as string]
             [schema.core :as s]
@@ -10,6 +9,7 @@
             [puppetlabs.puppetdb.archive :as archive]
             [clojure.java.io :as io]
             [puppetlabs.puppetdb.scf.storage-utils :as sutils]
+            [puppetlabs.puppetdb.cheshire :as json]
             [clojure.walk :as walk]
             [slingshot.slingshot :refer [try+ throw+]]
             [com.rpl.specter :as sp])
@@ -70,8 +70,7 @@
 
 (def export-root-dir "puppetdb-bak")
 
-(pls/defn-validated add-tar-entry
-  :- nil
+(pls/defn-validated add-tar-entry :- nil
   "Writes the given `tar-item` to `tar-writer` using
    export-root-directory as the base directory for contents"
   [tar-writer
@@ -80,6 +79,13 @@
                      (.getPath (apply io/file export-root-dir file-suffix))
                      contents))
 
+(defn read-json-content
+  "Utility function for our cli tools.
+  For reading json content from a tar-reader."
+  ([reader] (read-json-content reader false))
+  ([reader keywordize-keys?]
+   (-> reader archive/read-entry-content (json/parse-string keywordize-keys?))))
+
 (defmacro assoc-when
   "Assocs the provided values with the corresponding keys if and only
   if the key is not already present in map."
